===========================
Salt 2015.8.7 Release Notes
===========================

.. note::
    Salt 2015.8.4, 2015.8.5, and 2015.8.7 were all released within a short
    period due to regressions found soon after the releases of 2015.8.4 and
    2015.8.5. These release notes contain all of the changes since 2015.8.3 to
    make it easier to see everything that has changed recently.

Changes for v2015.8.4..v2015.8.7
--------------------------------

For :py:mod:`pkg.installed <salt.states.pkg.installed>` states, on Linux
distributions which use yum/dnf, packages which have a non-zero epoch in the
version number now require this epoch to be included when specifying an exact
version for a package. For example:

.. code-block:: yaml

    vim-enhanced:
      pkg.installed:
        - version: 2:7.4.160-1.el7

The :py:mod:`pkg.latest_version <salt.modules.yumpkg.latest_version>` and
:py:mod:`pkg.list_repo_pkgs <salt.modules.yumpkg.list_repo_pkgs>` functions can
be used to get the correct version string to use, as they will now contain the
epoch when it is non-zero.

Extended changelog courtesy of Todd Stansell (https://github.com/tjstansell/salt-changelogs):

*Generated at: 2016-02-11T22:13:51Z*

Statistics:

- Total Merges: **2**
- Total Issue references: **0**
- Total PR references: **3**

Changes:

- **PR** `#31111`_: (*jtand*) Fixes failing npm test on arch.
  @ *2016-02-10T21:51:47Z*

  * 8d84c63 Merge pull request `#31111`_ from jtand/8_4_npm_fix
  * b0a48e5 Fixes failing npm test on arch.

  * 733c6ab Some 3rd-party modules (e.g. gnupg) define custom log levels that emit at INFO level and above.  This patch sets the color data lookups to default to TextFormat('reset') rather than producing a stack trace every time a log message is generated from an affected module.

  * 3f71fd0 Revert `#30217`_

    - **PR** `#30217`_: (*pass-by-value*) Make sure cloud actions can be called via salt run

- **PR** `#31092`_: (*terminalmage*) Apply PR `#31031`_ to 2015.8.4.follow_up
  @ *2016-02-10T20:54:37Z*

  * 5a6a93e Merge pull request `#31092`_ from terminalmage/issue31014-2015.8.4.follow_up
    * 2767a4e Don't handle epoch specially for dnf

    * e5dfcc0 More efficient way to add the epoch before version number

    * ed74627 include possible epoch in version for rpm

  * 6c6b66a Comment multiprocessing line in minion config

  * 1f7dfef Set multiprocessing to true in config.py

  * 433c645 Fix remove placeholder files

  * 7103756 Remove placeholder files

  * 20b381f Set overwrite to off

  * ca50f56 Fix boto_secgroup

  * fd571d2 Fix boto test failures

  * cfb6588 Fix regression when contents_pillar/contents_grains is a list.

  * 881d866 utils.aws: use time lib to conver to epoch seconds

  * 3141292 The call to cp.get_url needs the saltenv, if you're using environments other than base, it will fail.

  * a869401 Fix regression in git_pillar when multiple remotes are configured

  * 2243f25 Properly set the default value for pillar_merge_lists

  * c7472ff Lint

  * d868711 Fix failing boto_vpc module unit tests

  * ed09516 Fix failing state module tests

  * fd0e940 Pylint fix

  * bc780a7 Don't use pack=pack. Just pass in pack=__salt__ always.

  * 1ae022d Pass in 'pack' variable to utils.boto.assign_funcs function from ALL boto modules.

  * 1efaff1 Remove bad symlinks in osx pkg dirs

  * c7db435 Fix regression in scanning for state with 'name' param

.. _`#30217`: https://github.com/saltstack/salt/pull/30217
.. _`#31031`: https://github.com/saltstack/salt/issues/31031
.. _`#31092`: https://github.com/saltstack/salt/pull/31092
.. _`#31111`: https://github.com/saltstack/salt/pull/31111

--------------------------

.. include:: 2015.8.4.rst
   :start-line: 17

